#
# Procedure defining the differential equation model
# for a mutating HIV interaction, from the book
# E. K. Yeargers, R. W. Shonkwiler and J. V. Herod,
# An introduction to the Mathematics of Biology
#    with computer algebra models,
# Birkhaeuser, 1996, pp. 348--357.
#
# There are N = 2*n+1 components:
# y[i] = v[i] = population of i'th viral mutant, i = 1..n,
# y[n+i] = x[i] = population of immune agent specific to v[i],
#                 i = 1..n,
# y[2*n+1] = z = population of general immune agents
#
#
MutantTemplate := proc( N, t, y, yp, parms)
  local v, x, z, i, s, n;
  # Use "subs" to replace the
  # parameters a, b, c, g, h, k with their
  # numerical values:, e.g.
  # f := subs( [a=5,b=4,c=5,g=1,h=1,k=1], op(MutantTemplate) );
  #
  n := trunc((N-1)/2);
  s := 0;
  for i to n do s := s + y[i] end do;
  for i to n do
    yp[i] := y[i]*(  a - b*y[N] - c*y[i+n] );
    yp[i+n] := g*y[i] - k*y[i+n]*s;
  end do;
  yp[N] := (h-k*y[N])*s;
end proc:
